#ifndef __PLUGIN_H__
#define __PLUGIN_H__

#include <string>		// String function definitions
#include <vector>		//
using namespace std;

/**
 * Generic interface for TuxLCD plugins.
 *
 * \author David Bull
 * \version 0.1
 * \date Monday 7th August 2006
 */
class Plugin
{
	private:
	
	public:	
		/**
		 * Destrustor.
		 */
		virtual ~Plugin() { }
		
		
		/**
		 * Returns the name of this plugin.
		 * \return the plugin name.
		 */
		virtual const char* getPluginName() = 0;
		
		
		/**
		 * Returns a list of properties available from this plugin.
		 * Property values can then be retrieved by calling getProperty(propertyName).
		 * \see getProperty(propertyName).
		 * \return a list of properties available from this plugin.
		 */
		virtual vector<string> getProperties() = 0;
		
		
		/**
		 * Returns the value of the specified property, or NULL ifthe propertyName is not valid.
		 * A list of valid property names is available from getProperties().
		 * \see getProperties()
		 * \param[in] propertyName the name of the property.
		 * \return the value of the specified property, or NULL if the propertyName is not valid.
		 */
		virtual char* getProperty(const char *propertyName) = 0;
		
		
		/**
		 * Outputs all properties and their values to stdout.
		 * Used for testing and debugging.
		 */
		virtual void dumpProperties() = 0;
};

// the types of the class factories
typedef Plugin* create_plugin_t(void*);
typedef void destroy_plugin_t(Plugin*);

#endif
